==> zaproxy-2.13.0.tar.gz: zaproxy-2.13.0/LEGALNOTICE.md <==
COPYRIGHT
---------

OWASP Zed Attack Proxy (ZAP)

The software package is:

    Copyright © 2010-2022 ZAP Development Team

Individual contributions, components, and libraries are copyright of their
respective authors.

SOFTWARE LICENSE
----------------

The open source software license of OWASP Zed Attack Proxy is Apache 2.0.
A copy of the Apache 2.0 license has been included in this software package
in ApacheLicense-2.0.txt.

THIRD-PARTY SOFTWARE LICENSES
-----------------------------

ZAP is a fork of Paros Proxy 3.2.13 developed by Chinotec Technologies Company
and licensed under the Clarified Artistic License.

In October 2014, imported files licensed under the GPL were relicensed with
permission from the authors under Apache 2.0.

The following components/libraries are distributed in this package,
and subject to their respective licenses.

| Library                             | License                   |
|-------------------------------------|---------------------------|
| commons-beanutils-1.9.4.jar         | Apache 2.0                |
| commons-codec-1.16.0.jar            | Apache 2.0                |
| commons-collections-3.2.2.jar       | Apache 2.0                |
| commons-configuration-1.10.jar      | Apache 2.0                |
| commons-csv-1.10.0.jar              | Apache 2.0                |
| commons-httpclient-3.1.jar          | Apache 2.0                |
| commons-io-2.13.0.jar               | Apache 2.0                |
| commons-lang-2.6.jar                | Apache 2.0                |
| commons-lang3-3.12.0.jar            | Apache 2.0                |
| commons-logging-1.2.jar             | Apache 2.0                |
| commons-text-1.10.0.jar             | Apache 2.0                |
| ezmorph-1.0.6.jar                   | Apache 2.0                |
| flatlaf-3.1.1.jar                   | Apache 2.0                |
| harlib-1.1.3.jar                    | Apache 2.0                |
| hsqldb-2.7.2.jar                    | BSD                       |
| jackson-core-asl-1.9.13.jar         | Apache 2.0                |
| javahelp-2.0.05.jar                 | GPL + classpath exception |
| java-semver-0.9.0.jar               | MIT                       |
| jericho-html-3.4.jar                | EPL / LGPL dual license   |
| jfreechart-1.5.4.jar                | LGPL                      |
| jgrapht-core-0.9.0.jar              | LGPL 2.1                  |
| json-lib-2.4-jdk15.jar              | MIT + "Good, Not Evil"    |
| log4j-1.2-api-2.20.0.jar            | Apache 2.0                |
| log4j-api-2.20.0.jar                | Apache 2.0                |
| log4j-core-2.20.0.jar               | Apache 2.0                |
| rsyntaxtextarea-3.3.3.jar           | BSD-3 clause              |
| swingx-all-1.6.5-1.jar              | LGPL 2.1                  |
| xom-1.3.9.jar                       | LGPL                      |

==> zaproxy-2.14.0.tar.gz: zaproxy-2.14.0/LEGALNOTICE.md <==
COPYRIGHT
---------

Zed Attack Proxy (ZAP)

The software package is:

    Copyright © 2010-2022 ZAP Development Team

Individual contributions, components, and libraries are copyright of their
respective authors.

SOFTWARE LICENSE
----------------

The open source software license of Zed Attack Proxy is Apache 2.0.
A copy of the Apache 2.0 license has been included in this software package
in ApacheLicense-2.0.txt.

THIRD-PARTY SOFTWARE LICENSES
-----------------------------

ZAP is a fork of Paros Proxy 3.2.13 developed by Chinotec Technologies Company
and licensed under the Clarified Artistic License.

In October 2014, imported files licensed under the GPL were relicensed with
permission from the authors under Apache 2.0.

The following components/libraries are distributed in this package,
and subject to their respective licenses.

| Library                             | License                   |
|-------------------------------------|---------------------------|
| commons-beanutils-1.9.4.jar         | Apache 2.0                |
| commons-codec-1.16.0.jar            | Apache 2.0                |
| commons-collections-3.2.2.jar       | Apache 2.0                |
| commons-configuration-1.10.jar      | Apache 2.0                |
| commons-csv-1.10.0.jar              | Apache 2.0                |
| commons-httpclient-3.1.jar          | Apache 2.0                |
| commons-io-2.13.0.jar               | Apache 2.0                |
| commons-lang-2.6.jar                | Apache 2.0                |
| commons-lang3-3.13.0.jar            | Apache 2.0                |
| commons-logging-1.2.jar             | Apache 2.0                |
| commons-text-1.10.0.jar             | Apache 2.0                |
| ezmorph-1.0.6.jar                   | Apache 2.0                |
| flatlaf-3.2.1.jar                   | Apache 2.0                |
| harlib-1.1.3.jar                    | Apache 2.0                |
| hsqldb-2.7.2.jar                    | BSD                       |
| jackson-core-asl-1.9.13.jar         | Apache 2.0                |
| javahelp-2.0.05.jar                 | GPL + classpath exception |
| java-semver-0.9.0.jar               | MIT                       |
| jericho-html-3.4.jar                | EPL / LGPL dual license   |
| jfreechart-1.5.4.jar                | LGPL                      |
| jgrapht-core-0.9.0.jar              | LGPL 2.1                  |
| json-lib-2.4-jdk15.jar              | MIT + "Good, Not Evil"    |
| log4j-1.2-api-2.20.0.jar            | Apache 2.0                |
| log4j-api-2.20.0.jar                | Apache 2.0                |
| log4j-core-2.20.0.jar               | Apache 2.0                |
| log4j-jul-2.20.0.jar                | Apache 2.0                |
| rsyntaxtextarea-3.3.4.jar           | BSD-3 clause              |
| swingx-all-1.6.5-1.jar              | LGPL 2.1                  |
| xom-1.3.9.jar                       | LGPL                      |
